Given a set of templates and a path, returns the template that is the closest match.
A score between 0.0 and 1.0 is returned along with the matching template; the closer
to 1.0, the more exact the match. Returns an error if the matching process failed for
any reason.
Given a set of templates and a path, returns the template that is the closest match.
A score between 0.0 and 1.0 is returned along with the matching template; the closer
to 1.0, the more exact the match. Returns an error if the matching process failed for
any reason.